@@ -95,18 +95,18 @@ mod util;
 
 // Modules that are always public.
 
-/// GenQuery.
+/// General Query.
 pub mod genquery;
 
+/// WebQuery struct with http support.
+pub mod web;
+
 /// Initial SQL
 pub mod init;
 
 /// Backing storage for database.
 pub mod stg;
 
-/// WebQuery struct for making a http web server.
-pub mod web;
-
 /// Page storage.
 pub mod pstore;
 
@@ -178,12 +178,6 @@ pub mod sortedfile;
 #[cfg(not(feature = "internal"))]
 mod sortedfile;
 
-#[cfg(feature = "internal")]
-/// Stash to retain page values at different times.
-pub mod stash;
-#[cfg(not(feature = "internal"))]
-mod stash;
-
 #[cfg(feature = "internal")]
 /// System table functions.
 pub mod sys;
